catch {TE::UTILS::te_msg TE_BD-0 INFO "This block design tcl-file was generate with Trenz Electronic GmbH Board Part:trenz.biz:te0729_20_2i:part0:1.0, FPGA: xc7z020clg484-2 at 2024-06-13T16:45:12."}
catch {TE::UTILS::te_msg TE_BD-1 INFO "This block design tcl-file was modified by TE-Scripts. Modifications are labelled with comment tag  # #TE_MOD# on the Block-Design tcl-file."}

if { ![info exist TE::VERSION_CONTROL] } {
  namespace eval ::TE  {
    set ::TE::VERSION_CONTROL true
  }
}
################################################################
# Check if script is running in correct Vivado version.
################################################################
set scripts_vivado_version 2023.2
set current_vivado_version [version -short ]
if { [string first $scripts_vivado_version $current_vivado_version] == -1 &&  $TE::VERSION_CONTROL } {
   puts ""
   catch {common::send_msg_id "BD_TCL-109" "ERROR" "This script was generated using Vivado < $scripts_vivado_version> and is being run in < $current_vivado_version> of Vivado. Please run the script in Vivado < $scripts_vivado_version> then open the design in Vivado < $current_vivado_version>. Upgrade the design by running "Tools => Report => Report IP Status...", then run write_bd_tcl to create an updated script."}
 return 1
}

################################################################
# This is a generated script based on design: zsys
#
# Though there are limitations about the generated script,
# the main purpose of this utility is to make learning
# IP Integrator Tcl commands easier.
################################################################

namespace eval _tcl {
proc get_script_folder {} {
   set script_path [file normalize [info script]]
   set script_folder [file dirname $script_path]
   return $script_folder
}
}
variable script_folder
set script_folder [_tcl::get_script_folder]

################################################################
# Check if script is running in correct Vivado version.
################################################################
set scripts_vivado_version 2023.2
set current_vivado_version [version -short]

if { [string first $scripts_vivado_version $current_vivado_version] == -1 } {
   puts ""
   common::send_gid_msg -ssname BD::TCL -id 2040 -severity "CRITICAL WARNING" "This script was generated using Vivado <$scripts_vivado_version> without IP versions in the create_bd_cell commands, but is now being run in <$current_vivado_version> of Vivado. There may have been changes to the IP between Vivado <$scripts_vivado_version> and <$current_vivado_version>, which could impact the functionality and configuration of the design."

}

################################################################
# START
################################################################

# To test this script, run the following commands from Vivado Tcl console:
# source zsys_script.tcl

# If there is no project opened, this script will create a
# project, but make sure you do not have an existing project
# <./myproj/project_1.xpr> in the current working folder.

set list_projs [get_projects -quiet]
if { $list_projs eq "" } {
   create_project project_1 myproj -part xc7z020clg484-2
   set_property BOARD_PART trenz.biz:te0729_20_2i:part0:1.0 [current_project]
}


# CHANGE DESIGN NAME HERE
variable design_name
set design_name zsys

# If you do not already have an existing IP Integrator design open,
# you can create a design using the following command:
#    create_bd_design $design_name

# Creating design if needed
set errMsg ""
set nRet 0

set cur_design [current_bd_design -quiet]
set list_cells [get_bd_cells -quiet]

if { ${design_name} eq "" } {
   # USE CASES:
   #    1) Design_name not set

   set errMsg "Please set the variable <design_name> to a non-empty value."
   set nRet 1

} elseif { ${cur_design} ne "" && ${list_cells} eq "" } {
   # USE CASES:
   #    2): Current design opened AND is empty AND names same.
   #    3): Current design opened AND is empty AND names diff; design_name NOT in project.
   #    4): Current design opened AND is empty AND names diff; design_name exists in project.

   if { $cur_design ne $design_name } {
      common::send_gid_msg -ssname BD::TCL -id 2001 -severity "INFO" "Changing value of <design_name> from <$design_name> to <$cur_design> since current design is empty."
      set design_name [get_property NAME $cur_design]
   }
   common::send_gid_msg -ssname BD::TCL -id 2002 -severity "INFO" "Constructing design in IPI design <$cur_design>..."

} elseif { ${cur_design} ne "" && $list_cells ne "" && $cur_design eq $design_name } {
   # USE CASES:
   #    5) Current design opened AND has components AND same names.

   set errMsg "Design <$design_name> already exists in your project, please set the variable <design_name> to another value."
   set nRet 1
} elseif { [get_files -quiet ${design_name}.bd] ne "" } {
   # USE CASES: 
   #    6) Current opened design, has components, but diff names, design_name exists in project.
   #    7) No opened design, design_name exists in project.

   set errMsg "Design <$design_name> already exists in your project, please set the variable <design_name> to another value."
   set nRet 2

} else {
   # USE CASES:
   #    8) No opened design, design_name not in project.
   #    9) Current opened design, has components, but diff names, design_name not in project.

   common::send_gid_msg -ssname BD::TCL -id 2003 -severity "INFO" "Currently there is no design <$design_name> in project, so creating one..."

   create_bd_design $design_name

   common::send_gid_msg -ssname BD::TCL -id 2004 -severity "INFO" "Making design <$design_name> as current_bd_design."
   current_bd_design $design_name

}

common::send_gid_msg -ssname BD::TCL -id 2005 -severity "INFO" "Currently the variable <design_name> is equal to \"$design_name\"."

if { $nRet != 0 } {
   catch {common::send_gid_msg -ssname BD::TCL -id 2006 -severity "ERROR" $errMsg}
   return $nRet
}

set bCheckIPsPassed 1
##################################################################
# CHECK IPs
##################################################################
set bCheckIPs 1
if { $bCheckIPs == 1 } {
   set list_check_ips "\ 
xilinx.com:ip:axi_ethernetlite:*\
xilinx.com:ip:processing_system7:*\
xilinx.com:ip:proc_sys_reset:*\
xilinx.com:ip:xlconcat:*\
trenz.biz:user:STARTUP:*\
xilinx.com:ip:c_counter_binary:*\
trenz.biz:user:labtools_fmeter:*\
xilinx.com:ip:util_vector_logic:*\
xilinx.com:ip:vio:*\
xilinx.com:ip:xlslice:*\
"

   set list_ips_missing ""
   common::send_gid_msg -ssname BD::TCL -id 2011 -severity "INFO" "Checking if the following IPs exist in the project's IP catalog: $list_check_ips ."

   foreach ip_vlnv $list_check_ips {
      set ip_obj [get_ipdefs -all $ip_vlnv]
      if { $ip_obj eq "" } {
         lappend list_ips_missing $ip_vlnv
      }
   }

   if { $list_ips_missing ne "" } {
      catch {common::send_gid_msg -ssname BD::TCL -id 2012 -severity "ERROR" "The following IPs are not found in the IP Catalog:\n  $list_ips_missing\n\nResolution: Please add the repository containing the IP(s) to the project." }
      set bCheckIPsPassed 0
   }

}

if { $bCheckIPsPassed != 1 } {
  common::send_gid_msg -ssname BD::TCL -id 2023 -severity "WARNING" "Will not continue with creation of design due to the error(s) above."
  return 3
}

##################################################################
# DESIGN PROCs
##################################################################


# Hierarchical cell: WD_CTRL
proc create_hier_cell_WD_CTRL { parentCell nameHier } {

  variable script_folder

  if { $parentCell eq "" || $nameHier eq "" } {
     catch {common::send_gid_msg -ssname BD::TCL -id 2092 -severity "ERROR" "create_hier_cell_WD_CTRL() - Empty argument(s)!"}
     return
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     catch {common::send_gid_msg -ssname BD::TCL -id 2090 -severity "ERROR" "Unable to find parent cell <$parentCell>!"}
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     catch {common::send_gid_msg -ssname BD::TCL -id 2091 -severity "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj

  # Create cell and set as current instance
  set hier_obj [create_bd_cell -type hier $nameHier]
  current_bd_instance $hier_obj

  # Create interface pins

  # Create pins
  create_bd_pin -dir I -from 0 -to 0 FCLK_0_IN
  create_bd_pin -dir O -from 0 -to 0 WDI_HIT_OUT
  create_bd_pin -dir O -from 0 -to 0 WD_EN_OUT

  # Create instance: STARTUP_0, and set properties
  set STARTUP_0 [ create_bd_cell -type ip -vlnv trenz.biz:user:STARTUP STARTUP_0 ]

  # Create instance: c_counter_binary_0, and set properties
  set c_counter_binary_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:c_counter_binary c_counter_binary_0 ]
  set_property CONFIG.Output_Width {25} $c_counter_binary_0


  # Create instance: labtools_fmeter_0, and set properties
  set labtools_fmeter_0 [ create_bd_cell -type ip -vlnv trenz.biz:user:labtools_fmeter labtools_fmeter_0 ]
  set_property -dict [list \
    CONFIG.C_CHANNELS {4} \
    CONFIG.C_REFCLK_HZ {66000000} \
  ] $labtools_fmeter_0


  # Create instance: util_vector_logic_0, and set properties
  set util_vector_logic_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_vector_logic util_vector_logic_0 ]
  set_property CONFIG.C_SIZE {1} $util_vector_logic_0


  # Create instance: util_vector_logic_1, and set properties
  set util_vector_logic_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_vector_logic util_vector_logic_1 ]
  set_property CONFIG.C_SIZE {1} $util_vector_logic_1


  # Create instance: util_vector_logic_2, and set properties
  set util_vector_logic_2 [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_vector_logic util_vector_logic_2 ]
  set_property CONFIG.C_SIZE {1} $util_vector_logic_2


  # Create instance: util_vector_logic_3, and set properties
  set util_vector_logic_3 [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_vector_logic util_vector_logic_3 ]
  set_property CONFIG.C_SIZE {1} $util_vector_logic_3


  # Create instance: util_vector_logic_4, and set properties
  set util_vector_logic_4 [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_vector_logic util_vector_logic_4 ]
  set_property CONFIG.C_SIZE {1} $util_vector_logic_4


  # Create instance: util_vector_logic_5, and set properties
  set util_vector_logic_5 [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_vector_logic util_vector_logic_5 ]
  set_property -dict [list \
    CONFIG.C_OPERATION {or} \
    CONFIG.C_SIZE {1} \
  ] $util_vector_logic_5


  # Create instance: util_vector_logic_6, and set properties
  set util_vector_logic_6 [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_vector_logic util_vector_logic_6 ]
  set_property -dict [list \
    CONFIG.C_OPERATION {or} \
    CONFIG.C_SIZE {1} \
  ] $util_vector_logic_6


  # Create instance: util_vector_logic_7, and set properties
  set util_vector_logic_7 [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_vector_logic util_vector_logic_7 ]
  set_property -dict [list \
    CONFIG.C_OPERATION {or} \
    CONFIG.C_SIZE {1} \
  ] $util_vector_logic_7


  # Create instance: util_vector_logic_8, and set properties
  set util_vector_logic_8 [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_vector_logic util_vector_logic_8 ]
  set_property -dict [list \
    CONFIG.C_OPERATION {or} \
    CONFIG.C_SIZE {1} \
  ] $util_vector_logic_8


  # Create instance: vio_0, and set properties
  set vio_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:vio vio_0 ]
  set_property -dict [list \
    CONFIG.C_NUM_PROBE_IN {5} \
    CONFIG.C_NUM_PROBE_OUT {6} \
  ] $vio_0


  # Create instance: xlconcat_0, and set properties
  set xlconcat_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat xlconcat_0 ]
  set_property CONFIG.NUM_PORTS {1} $xlconcat_0


  # Create instance: xlconcat_1, and set properties
  set xlconcat_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat xlconcat_1 ]
  set_property CONFIG.NUM_PORTS {4} $xlconcat_1


  # Create instance: xlslice_sel5, and set properties
  set xlslice_sel5 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlslice xlslice_sel5 ]
  set_property -dict [list \
    CONFIG.DIN_FROM {5} \
    CONFIG.DIN_TO {5} \
    CONFIG.DIN_WIDTH {25} \
    CONFIG.DOUT_WIDTH {1} \
  ] $xlslice_sel5


  # Create instance: xlslice_sel9, and set properties
  set xlslice_sel9 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlslice xlslice_sel9 ]
  set_property -dict [list \
    CONFIG.DIN_FROM {9} \
    CONFIG.DIN_TO {9} \
    CONFIG.DIN_WIDTH {25} \
    CONFIG.DOUT_WIDTH {1} \
  ] $xlslice_sel9


  # Create instance: xlslice_sel14, and set properties
  set xlslice_sel14 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlslice xlslice_sel14 ]
  set_property -dict [list \
    CONFIG.DIN_FROM {14} \
    CONFIG.DIN_TO {14} \
    CONFIG.DIN_WIDTH {25} \
    CONFIG.DOUT_WIDTH {1} \
  ] $xlslice_sel14


  # Create instance: xlslice_sel19, and set properties
  set xlslice_sel19 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlslice xlslice_sel19 ]
  set_property -dict [list \
    CONFIG.DIN_FROM {19} \
    CONFIG.DIN_TO {19} \
    CONFIG.DIN_WIDTH {25} \
    CONFIG.DOUT_WIDTH {1} \
  ] $xlslice_sel19


  # Create instance: xlslice_sel24, and set properties
  set xlslice_sel24 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlslice xlslice_sel24 ]
  set_property -dict [list \
    CONFIG.DIN_FROM {24} \
    CONFIG.DIN_TO {24} \
    CONFIG.DIN_WIDTH {25} \
    CONFIG.DOUT_WIDTH {1} \
  ] $xlslice_sel24


  # Create port connections
  connect_bd_net -net STARTUP_0_user_clk [get_bd_pins STARTUP_0/user_clk] [get_bd_pins c_counter_binary_0/CLK] [get_bd_pins labtools_fmeter_0/refclk] [get_bd_pins vio_0/clk]
  connect_bd_net -net WDI_EN [get_bd_pins vio_0/probe_out0] [get_bd_pins xlconcat_0/In0]
  connect_bd_net -net WDI_HIT_0_EN_MAX_CLK [get_bd_pins vio_0/probe_out1] [get_bd_pins util_vector_logic_0/Op1]
  connect_bd_net -net WDI_HIT_1_EN_CLK [get_bd_pins vio_0/probe_out2] [get_bd_pins util_vector_logic_1/Op1]
  connect_bd_net -net WDI_HIT_2_EN_CLK [get_bd_pins vio_0/probe_out3] [get_bd_pins util_vector_logic_2/Op1]
  connect_bd_net -net WDI_HIT_3_EN_CLK [get_bd_pins vio_0/probe_out4] [get_bd_pins util_vector_logic_3/Op1]
  connect_bd_net -net WDI_HIT_4_EN_MINCLK [get_bd_pins vio_0/probe_out5] [get_bd_pins util_vector_logic_4/Op1]
  connect_bd_net -net WD_HIT [get_bd_pins util_vector_logic_5/Res] [get_bd_pins WDI_HIT_OUT] [get_bd_pins xlconcat_1/In2]
  connect_bd_net -net c_counter_binary_0_Q [get_bd_pins c_counter_binary_0/Q] [get_bd_pins xlslice_sel14/Din] [get_bd_pins xlslice_sel19/Din] [get_bd_pins xlslice_sel24/Din] [get_bd_pins xlslice_sel5/Din] [get_bd_pins xlslice_sel9/Din]
  connect_bd_net -net fm_psfclk0_50mhz [get_bd_pins labtools_fmeter_0/F0] [get_bd_pins vio_0/probe_in0]
  connect_bd_net -net fm_wdi_max_1p03mhz [get_bd_pins labtools_fmeter_0/F1] [get_bd_pins vio_0/probe_in1]
  connect_bd_net -net fm_wdi_min_982khz [get_bd_pins labtools_fmeter_0/F3] [get_bd_pins vio_0/probe_in3]
  connect_bd_net -net fm_wdi_set [get_bd_pins labtools_fmeter_0/F2] [get_bd_pins vio_0/probe_in2]
  connect_bd_net -net labtools_fmeter_0_update [get_bd_pins labtools_fmeter_0/update] [get_bd_pins vio_0/probe_in4]
  connect_bd_net -net processing_system7_0_FCLK_CLK0 [get_bd_pins FCLK_0_IN] [get_bd_pins xlconcat_1/In0]
  connect_bd_net -net util_vector_logic_0_Res [get_bd_pins util_vector_logic_0/Res] [get_bd_pins util_vector_logic_6/Op1]
  connect_bd_net -net util_vector_logic_1_Res [get_bd_pins util_vector_logic_1/Res] [get_bd_pins util_vector_logic_6/Op2]
  connect_bd_net -net util_vector_logic_2_Res [get_bd_pins util_vector_logic_2/Res] [get_bd_pins util_vector_logic_7/Op1]
  connect_bd_net -net util_vector_logic_3_Res [get_bd_pins util_vector_logic_3/Res] [get_bd_pins util_vector_logic_7/Op2]
  connect_bd_net -net util_vector_logic_4_Res [get_bd_pins util_vector_logic_4/Res] [get_bd_pins util_vector_logic_8/Op2]
  connect_bd_net -net util_vector_logic_6_Res [get_bd_pins util_vector_logic_6/Res] [get_bd_pins util_vector_logic_5/Op1]
  connect_bd_net -net util_vector_logic_7_Res [get_bd_pins util_vector_logic_7/Res] [get_bd_pins util_vector_logic_8/Op1]
  connect_bd_net -net util_vector_logic_8_Res [get_bd_pins util_vector_logic_8/Res] [get_bd_pins util_vector_logic_5/Op2]
  connect_bd_net -net xlconcat_0_dout [get_bd_pins xlconcat_0/dout] [get_bd_pins WD_EN_OUT]
  connect_bd_net -net xlconcat_1_dout [get_bd_pins xlconcat_1/dout] [get_bd_pins labtools_fmeter_0/fin]
  connect_bd_net -net xlslice_0_Dout [get_bd_pins xlslice_sel5/Dout] [get_bd_pins util_vector_logic_0/Op2] [get_bd_pins xlconcat_1/In1]
  connect_bd_net -net xlslice_1_Dout [get_bd_pins xlslice_sel24/Dout] [get_bd_pins util_vector_logic_4/Op2] [get_bd_pins xlconcat_1/In3]
  connect_bd_net -net xlslice_sel14_Dout [get_bd_pins xlslice_sel14/Dout] [get_bd_pins util_vector_logic_2/Op2]
  connect_bd_net -net xlslice_sel19_Dout [get_bd_pins xlslice_sel19/Dout] [get_bd_pins util_vector_logic_3/Op2]
  connect_bd_net -net xlslice_sel9_Dout [get_bd_pins xlslice_sel9/Dout] [get_bd_pins util_vector_logic_1/Op2]

  # Restore current instance
  current_bd_instance $oldCurInst
}


# Procedure to create entire design; Provide argument to make
# procedure reusable. If parentCell is "", will use root.
proc create_root_design { parentCell } {

  variable script_folder
  variable design_name

  if { $parentCell eq "" } {
     set parentCell [get_bd_cells /]
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     catch {common::send_gid_msg -ssname BD::TCL -id 2090 -severity "ERROR" "Unable to find parent cell <$parentCell>!"}
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     catch {common::send_gid_msg -ssname BD::TCL -id 2091 -severity "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj


  # Create interface ports
  set ETH0_MDIO_MDC [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:mdio_rtl:1.0 ETH0_MDIO_MDC ]

  set ETH0_MII [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:mii_rtl:1.0 ETH0_MII ]

  set ETH1_MDIO_MDC [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:mdio_rtl:1.0 ETH1_MDIO_MDC ]

  set ETH1_MII [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:mii_rtl:1.0 ETH1_MII ]

# #TE_MOD#   set DDR [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:ddrx_rtl:1.0 DDR ]

# #TE_MOD#   set FIXED_IO [ create_bd_intf_port -mode Master -vlnv xilinx.com:display_processing_system7:fixedio_rtl:1.0 FIXED_IO ]


  # Create ports
  set FPGA_IO [ create_bd_port -dir O -from 0 -to 0 FPGA_IO ]
  set WDI_EN [ create_bd_port -dir O -from 0 -to 0 WDI_EN ]
  set WD_HIT [ create_bd_port -dir O -from 0 -to 0 WD_HIT ]

  # Create instance: WD_CTRL
  create_hier_cell_WD_CTRL [current_bd_instance .] WD_CTRL

  # Create instance: axi_ethernetlite_0, and set properties
  set axi_ethernetlite_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_ethernetlite axi_ethernetlite_0 ]
  set_property -dict [list \
    CONFIG.MDIO_BOARD_INTERFACE {ETH0_MDIO_MDC} \
    CONFIG.MII_BOARD_INTERFACE {ETH0_MII} \
    CONFIG.USE_BOARD_FLOW {true} \
  ] $axi_ethernetlite_0


  # Create instance: axi_ethernetlite_1, and set properties
  set axi_ethernetlite_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_ethernetlite axi_ethernetlite_1 ]
  set_property -dict [list \
    CONFIG.MDIO_BOARD_INTERFACE {ETH1_MDIO_MDC} \
    CONFIG.MII_BOARD_INTERFACE {ETH1_MII} \
    CONFIG.USE_BOARD_FLOW {true} \
  ] $axi_ethernetlite_1


  # Create instance: processing_system7_0, and set properties
  set processing_system7_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:processing_system7 processing_system7_0 ]
# #TE_MOD#_Add next line#
  apply_bd_automation -rule xilinx.com:bd_rule:processing_system7 -config {make_external "FIXED_IO, DDR" apply_board_preset "1"}  [get_bd_cells processing_system7_0]
# #TE_MOD#_Add next line#
  set tcl_pr_ext [];if { [catch {set tcl_pr_ext [glob -join -dir ${TE::BOARDDEF_PATH}/preset_extension/ *_preset.tcl]}] } {};foreach preset_ext $tcl_pr_ext { source  $preset_ext};
# #TE_MOD#   set_property -dict [list \
# #TE_MOD#   ] $processing_system7_0

# #TE_MOD#     CONFIG.PCW_ACT_APU_PERIPHERAL_FREQMHZ {666.666626} \
# #TE_MOD#     CONFIG.PCW_ACT_CAN_PERIPHERAL_FREQMHZ {10.000000} \
# #TE_MOD#     CONFIG.PCW_ACT_DCI_PERIPHERAL_FREQMHZ {10.158729} \
# #TE_MOD#     CONFIG.PCW_ACT_ENET0_PERIPHERAL_FREQMHZ {124.999985} \
# #TE_MOD#     CONFIG.PCW_ACT_ENET1_PERIPHERAL_FREQMHZ {10.000000} \
# #TE_MOD#     CONFIG.PCW_ACT_FPGA0_PERIPHERAL_FREQMHZ {99.999985} \
# #TE_MOD#     CONFIG.PCW_ACT_FPGA1_PERIPHERAL_FREQMHZ {10.000000} \
# #TE_MOD#     CONFIG.PCW_ACT_FPGA2_PERIPHERAL_FREQMHZ {10.000000} \
# #TE_MOD#     CONFIG.PCW_ACT_FPGA3_PERIPHERAL_FREQMHZ {10.000000} \
# #TE_MOD#     CONFIG.PCW_ACT_PCAP_PERIPHERAL_FREQMHZ {199.999969} \
# #TE_MOD#     CONFIG.PCW_ACT_QSPI_PERIPHERAL_FREQMHZ {199.999969} \
# #TE_MOD#     CONFIG.PCW_ACT_SDIO_PERIPHERAL_FREQMHZ {99.999985} \
# #TE_MOD#     CONFIG.PCW_ACT_SMC_PERIPHERAL_FREQMHZ {10.000000} \
# #TE_MOD#     CONFIG.PCW_ACT_SPI_PERIPHERAL_FREQMHZ {10.000000} \
# #TE_MOD#     CONFIG.PCW_ACT_TPIU_PERIPHERAL_FREQMHZ {200.000000} \
# #TE_MOD#     CONFIG.PCW_ACT_TTC0_CLK0_PERIPHERAL_FREQMHZ {111.111107} \
# #TE_MOD#     CONFIG.PCW_ACT_TTC0_CLK1_PERIPHERAL_FREQMHZ {111.111107} \
# #TE_MOD#     CONFIG.PCW_ACT_TTC0_CLK2_PERIPHERAL_FREQMHZ {111.111107} \
# #TE_MOD#     CONFIG.PCW_ACT_TTC1_CLK0_PERIPHERAL_FREQMHZ {111.111107} \
# #TE_MOD#     CONFIG.PCW_ACT_TTC1_CLK1_PERIPHERAL_FREQMHZ {111.111107} \
# #TE_MOD#     CONFIG.PCW_ACT_TTC1_CLK2_PERIPHERAL_FREQMHZ {111.111107} \
# #TE_MOD#     CONFIG.PCW_ACT_UART_PERIPHERAL_FREQMHZ {99.999985} \
# #TE_MOD#     CONFIG.PCW_ACT_WDT_PERIPHERAL_FREQMHZ {111.111107} \
# #TE_MOD#     CONFIG.PCW_CLK0_FREQ {99999985} \
# #TE_MOD#     CONFIG.PCW_CLK1_FREQ {10000000} \
# #TE_MOD#     CONFIG.PCW_CLK2_FREQ {10000000} \
# #TE_MOD#     CONFIG.PCW_CLK3_FREQ {10000000} \
# #TE_MOD#     CONFIG.PCW_CRYSTAL_PERIPHERAL_FREQMHZ {33.33333} \
# #TE_MOD#     CONFIG.PCW_DDR_RAM_HIGHADDR {0x1FFFFFFF} \
# #TE_MOD#     CONFIG.PCW_ENET0_ENET0_IO {MIO 16 .. 27} \
# #TE_MOD#     CONFIG.PCW_ENET0_GRP_MDIO_ENABLE {1} \
# #TE_MOD#     CONFIG.PCW_ENET0_GRP_MDIO_IO {MIO 52 .. 53} \
# #TE_MOD#     CONFIG.PCW_ENET0_PERIPHERAL_ENABLE {1} \
# #TE_MOD#     CONFIG.PCW_ENET0_PERIPHERAL_FREQMHZ {1000 Mbps} \
# #TE_MOD#     CONFIG.PCW_ENET0_RESET_ENABLE {1} \
# #TE_MOD#     CONFIG.PCW_ENET0_RESET_IO {MIO 51} \
# #TE_MOD#     CONFIG.PCW_ENET_RESET_ENABLE {1} \
# #TE_MOD#     CONFIG.PCW_ENET_RESET_SELECT {Share reset pin} \
# #TE_MOD#     CONFIG.PCW_EN_EMIO_TTC0 {1} \
# #TE_MOD#     CONFIG.PCW_EN_EMIO_TTC1 {1} \
# #TE_MOD#     CONFIG.PCW_EN_EMIO_UART0 {0} \
# #TE_MOD#     CONFIG.PCW_EN_EMIO_WDT {1} \
# #TE_MOD#     CONFIG.PCW_EN_ENET0 {1} \
# #TE_MOD#     CONFIG.PCW_EN_GPIO {1} \
# #TE_MOD#     CONFIG.PCW_EN_I2C0 {1} \
# #TE_MOD#     CONFIG.PCW_EN_I2C1 {1} \
# #TE_MOD#     CONFIG.PCW_EN_QSPI {1} \
# #TE_MOD#     CONFIG.PCW_EN_SDIO0 {1} \
# #TE_MOD#     CONFIG.PCW_EN_TTC0 {1} \
# #TE_MOD#     CONFIG.PCW_EN_TTC1 {1} \
# #TE_MOD#     CONFIG.PCW_EN_UART0 {1} \
# #TE_MOD#     CONFIG.PCW_EN_USB0 {1} \
# #TE_MOD#     CONFIG.PCW_EN_WDT {1} \
# #TE_MOD#     CONFIG.PCW_FPGA0_PERIPHERAL_FREQMHZ {100} \
# #TE_MOD#     CONFIG.PCW_FPGA_FCLK0_ENABLE {1} \
# #TE_MOD#     CONFIG.PCW_GPIO_MIO_GPIO_ENABLE {1} \
# #TE_MOD#     CONFIG.PCW_GPIO_MIO_GPIO_IO {MIO} \
# #TE_MOD#     CONFIG.PCW_I2C0_GRP_INT_ENABLE {0} \
# #TE_MOD#     CONFIG.PCW_I2C0_I2C0_IO {MIO 10 .. 11} \
# #TE_MOD#     CONFIG.PCW_I2C0_PERIPHERAL_ENABLE {1} \
# #TE_MOD#     CONFIG.PCW_I2C1_GRP_INT_ENABLE {0} \
# #TE_MOD#     CONFIG.PCW_I2C1_I2C1_IO {MIO 12 .. 13} \
# #TE_MOD#     CONFIG.PCW_I2C1_PERIPHERAL_ENABLE {1} \
# #TE_MOD#     CONFIG.PCW_I2C_PERIPHERAL_FREQMHZ {111.111107} \
# #TE_MOD#     CONFIG.PCW_I2C_RESET_ENABLE {0} \
# #TE_MOD#     CONFIG.PCW_IRQ_F2P_INTR {1} \
# #TE_MOD#     CONFIG.PCW_MIO_0_IOTYPE {LVCMOS 3.3V} \
# #TE_MOD#     CONFIG.PCW_MIO_0_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_0_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_10_IOTYPE {LVCMOS 3.3V} \
# #TE_MOD#     CONFIG.PCW_MIO_10_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_10_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_11_IOTYPE {LVCMOS 3.3V} \
# #TE_MOD#     CONFIG.PCW_MIO_11_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_11_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_12_IOTYPE {LVCMOS 3.3V} \
# #TE_MOD#     CONFIG.PCW_MIO_12_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_12_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_13_IOTYPE {LVCMOS 3.3V} \
# #TE_MOD#     CONFIG.PCW_MIO_13_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_13_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_14_IOTYPE {LVCMOS 3.3V} \
# #TE_MOD#     CONFIG.PCW_MIO_14_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_14_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_15_IOTYPE {LVCMOS 3.3V} \
# #TE_MOD#     CONFIG.PCW_MIO_15_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_15_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_16_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_16_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_16_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_17_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_17_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_17_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_18_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_18_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_18_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_19_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_19_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_19_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_1_IOTYPE {LVCMOS 3.3V} \
# #TE_MOD#     CONFIG.PCW_MIO_1_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_1_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_20_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_20_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_20_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_21_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_21_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_21_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_22_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_22_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_22_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_23_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_23_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_23_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_24_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_24_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_24_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_25_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_25_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_25_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_26_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_26_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_26_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_27_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_27_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_27_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_28_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_28_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_28_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_29_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_29_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_29_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_2_IOTYPE {LVCMOS 3.3V} \
# #TE_MOD#     CONFIG.PCW_MIO_2_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_30_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_30_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_30_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_31_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_31_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_31_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_32_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_32_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_32_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_33_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_33_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_33_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_34_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_34_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_34_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_35_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_35_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_35_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_36_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_36_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_36_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_37_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_37_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_37_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_38_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_38_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_38_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_39_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_39_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_39_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_3_IOTYPE {LVCMOS 3.3V} \
# #TE_MOD#     CONFIG.PCW_MIO_3_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_40_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_40_PULLUP {disabled} \
# #TE_MOD#     CONFIG.PCW_MIO_40_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_41_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_41_PULLUP {disabled} \
# #TE_MOD#     CONFIG.PCW_MIO_41_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_42_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_42_PULLUP {disabled} \
# #TE_MOD#     CONFIG.PCW_MIO_42_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_43_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_43_PULLUP {disabled} \
# #TE_MOD#     CONFIG.PCW_MIO_43_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_44_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_44_PULLUP {disabled} \
# #TE_MOD#     CONFIG.PCW_MIO_44_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_45_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_45_PULLUP {disabled} \
# #TE_MOD#     CONFIG.PCW_MIO_45_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_46_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_46_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_46_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_47_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_47_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_47_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_48_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_48_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_48_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_49_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_49_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_49_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_4_IOTYPE {LVCMOS 3.3V} \
# #TE_MOD#     CONFIG.PCW_MIO_4_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_50_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_50_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_50_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_51_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_51_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_51_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_52_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_52_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_52_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_53_IOTYPE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_MIO_53_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_53_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_5_IOTYPE {LVCMOS 3.3V} \
# #TE_MOD#     CONFIG.PCW_MIO_5_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_6_IOTYPE {LVCMOS 3.3V} \
# #TE_MOD#     CONFIG.PCW_MIO_6_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_7_IOTYPE {LVCMOS 3.3V} \
# #TE_MOD#     CONFIG.PCW_MIO_7_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_8_IOTYPE {LVCMOS 3.3V} \
# #TE_MOD#     CONFIG.PCW_MIO_8_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_9_IOTYPE {LVCMOS 3.3V} \
# #TE_MOD#     CONFIG.PCW_MIO_9_PULLUP {enabled} \
# #TE_MOD#     CONFIG.PCW_MIO_9_SLEW {slow} \
# #TE_MOD#     CONFIG.PCW_MIO_TREE_PERIPHERALS {GPIO#Quad SPI Flash#Quad SPI Flash#Quad SPI Flash#Quad SPI Flash#Quad SPI Flash#Quad SPI Flash#GPIO#GPIO#GPIO#I2C 0#I2C 0#I2C 1#I2C 1#UART 0#UART 0#Enet 0#Enet 0#Enet\
# #TE_MOD# 0#Enet 0#Enet 0#Enet 0#Enet 0#Enet 0#Enet 0#Enet 0#Enet 0#Enet 0#USB 0#USB 0#USB 0#USB 0#USB 0#USB 0#USB 0#USB 0#USB 0#USB 0#USB 0#USB 0#SD 0#SD 0#SD 0#SD 0#SD 0#SD 0#GPIO#GPIO#GPIO#USB Reset#GPIO#ENET\
# #TE_MOD# Reset#Enet 0#Enet 0} \
# #TE_MOD#     CONFIG.PCW_MIO_TREE_SIGNALS {gpio[0]#qspi0_ss_b#qspi0_io[0]#qspi0_io[1]#qspi0_io[2]#qspi0_io[3]/HOLD_B#qspi0_sclk#gpio[7]#gpio[8]#gpio[9]#scl#sda#scl#sda#rx#tx#tx_clk#txd[0]#txd[1]#txd[2]#txd[3]#tx_ctl#rx_clk#rxd[0]#rxd[1]#rxd[2]#rxd[3]#rx_ctl#data[4]#dir#stp#nxt#data[0]#data[1]#data[2]#data[3]#clk#data[5]#data[6]#data[7]#clk#cmd#data[0]#data[1]#data[2]#data[3]#gpio[46]#gpio[47]#gpio[48]#reset#gpio[50]#reset#mdc#mdio}\
# #TE_MOD# \
# #TE_MOD#     CONFIG.PCW_PRESET_BANK0_VOLTAGE {LVCMOS 3.3V} \
# #TE_MOD#     CONFIG.PCW_PRESET_BANK1_VOLTAGE {LVCMOS 1.8V} \
# #TE_MOD#     CONFIG.PCW_QSPI_GRP_FBCLK_ENABLE {0} \
# #TE_MOD#     CONFIG.PCW_QSPI_GRP_IO1_ENABLE {0} \
# #TE_MOD#     CONFIG.PCW_QSPI_GRP_SINGLE_SS_ENABLE {1} \
# #TE_MOD#     CONFIG.PCW_QSPI_GRP_SINGLE_SS_IO {MIO 1 .. 6} \
# #TE_MOD#     CONFIG.PCW_QSPI_GRP_SS1_ENABLE {0} \
# #TE_MOD#     CONFIG.PCW_QSPI_PERIPHERAL_ENABLE {1} \
# #TE_MOD#     CONFIG.PCW_QSPI_PERIPHERAL_FREQMHZ {200} \
# #TE_MOD#     CONFIG.PCW_QSPI_QSPI_IO {MIO 1 .. 6} \
# #TE_MOD#     CONFIG.PCW_SD0_GRP_CD_ENABLE {0} \
# #TE_MOD#     CONFIG.PCW_SD0_GRP_POW_ENABLE {0} \
# #TE_MOD#     CONFIG.PCW_SD0_GRP_WP_ENABLE {0} \
# #TE_MOD#     CONFIG.PCW_SD0_PERIPHERAL_ENABLE {1} \
# #TE_MOD#     CONFIG.PCW_SD0_SD0_IO {MIO 40 .. 45} \
# #TE_MOD#     CONFIG.PCW_SDIO_PERIPHERAL_FREQMHZ {100} \
# #TE_MOD#     CONFIG.PCW_SDIO_PERIPHERAL_VALID {1} \
# #TE_MOD#     CONFIG.PCW_SINGLE_QSPI_DATA_MODE {x4} \
# #TE_MOD#     CONFIG.PCW_TTC0_PERIPHERAL_ENABLE {1} \
# #TE_MOD#     CONFIG.PCW_TTC0_TTC0_IO {EMIO} \
# #TE_MOD#     CONFIG.PCW_TTC1_PERIPHERAL_ENABLE {1} \
# #TE_MOD#     CONFIG.PCW_TTC1_TTC1_IO {EMIO} \
# #TE_MOD#     CONFIG.PCW_TTC_PERIPHERAL_FREQMHZ {50} \
# #TE_MOD#     CONFIG.PCW_UART0_GRP_FULL_ENABLE {0} \
# #TE_MOD#     CONFIG.PCW_UART0_PERIPHERAL_ENABLE {1} \
# #TE_MOD#     CONFIG.PCW_UART0_UART0_IO {MIO 14 .. 15} \
# #TE_MOD#     CONFIG.PCW_UART_PERIPHERAL_FREQMHZ {100} \
# #TE_MOD#     CONFIG.PCW_UART_PERIPHERAL_VALID {1} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_ACT_DDR_FREQ_MHZ {533.333252} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_BANK_ADDR_COUNT {3} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_BL {8} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY0 {0.007} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY1 {0.007} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY2 {0.007} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY3 {0.007} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_BUS_WIDTH {16 Bit} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_CL {7} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_COL_ADDR_COUNT {10} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_CWL {5.000000} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_DEVICE_CAPACITY {4096 MBits} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_DRAM_WIDTH {16 Bit} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_ECC {Disabled} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_MEMORY_TYPE {DDR 3} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_PARTNO {Custom} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_ROW_ADDR_COUNT {15} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_SPEED_BIN {DDR3_1066F} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_T_FAW {25} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_T_RAS_MIN {34.0} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_T_RC {48.91} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_T_RCD {7} \
# #TE_MOD#     CONFIG.PCW_UIPARAM_DDR_T_RP {7} \
# #TE_MOD#     CONFIG.PCW_USB0_PERIPHERAL_ENABLE {1} \
# #TE_MOD#     CONFIG.PCW_USB0_RESET_ENABLE {1} \
# #TE_MOD#     CONFIG.PCW_USB0_RESET_IO {MIO 49} \
# #TE_MOD#     CONFIG.PCW_USB0_USB0_IO {MIO 28 .. 39} \
# #TE_MOD#     CONFIG.PCW_USB_RESET_ENABLE {1} \
# #TE_MOD#     CONFIG.PCW_USB_RESET_SELECT {Share reset pin} \
# #TE_MOD#     CONFIG.PCW_USE_FABRIC_INTERRUPT {1} \
# #TE_MOD#     CONFIG.PCW_WDT_PERIPHERAL_ENABLE {1} \
# #TE_MOD#     CONFIG.PCW_WDT_WDT_IO {EMIO} \
# #TE_MOD# #Empty Line

  # Create instance: ps7_0_axi_periph, and set properties
  set ps7_0_axi_periph [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect ps7_0_axi_periph ]
  set_property -dict [list \
    CONFIG.NUM_MI {2} \
    CONFIG.SYNCHRONIZATION_STAGES {2} \
  ] $ps7_0_axi_periph


  # Create instance: rst_ps7_0_50M, and set properties
  set rst_ps7_0_50M [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset rst_ps7_0_50M ]

  # Create instance: xlconcat_0, and set properties
  set xlconcat_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat xlconcat_0 ]

  # Create interface connections
  connect_bd_intf_net -intf_net axi_ethernetlite_0_MDIO [get_bd_intf_ports ETH0_MDIO_MDC] [get_bd_intf_pins axi_ethernetlite_0/MDIO]
  connect_bd_intf_net -intf_net axi_ethernetlite_0_MII [get_bd_intf_ports ETH0_MII] [get_bd_intf_pins axi_ethernetlite_0/MII]
  connect_bd_intf_net -intf_net axi_ethernetlite_1_MDIO [get_bd_intf_ports ETH1_MDIO_MDC] [get_bd_intf_pins axi_ethernetlite_1/MDIO]
  connect_bd_intf_net -intf_net axi_ethernetlite_1_MII [get_bd_intf_ports ETH1_MII] [get_bd_intf_pins axi_ethernetlite_1/MII]
# #TE_MOD#   connect_bd_intf_net -intf_net processing_system7_0_DDR [get_bd_intf_ports DDR] [get_bd_intf_pins processing_system7_0/DDR]
# #TE_MOD#   connect_bd_intf_net -intf_net processing_system7_0_FIXED_IO [get_bd_intf_ports FIXED_IO] [get_bd_intf_pins processing_system7_0/FIXED_IO]
  connect_bd_intf_net -intf_net processing_system7_0_M_AXI_GP0 [get_bd_intf_pins processing_system7_0/M_AXI_GP0] [get_bd_intf_pins ps7_0_axi_periph/S00_AXI]
  connect_bd_intf_net -intf_net ps7_0_axi_periph_M00_AXI [get_bd_intf_pins axi_ethernetlite_0/S_AXI] [get_bd_intf_pins ps7_0_axi_periph/M00_AXI]
  connect_bd_intf_net -intf_net ps7_0_axi_periph_M01_AXI [get_bd_intf_pins axi_ethernetlite_1/S_AXI] [get_bd_intf_pins ps7_0_axi_periph/M01_AXI]

  # Create port connections
  connect_bd_net -net WDI_EN_FPGA_IO [get_bd_pins WD_CTRL/WD_EN_OUT] [get_bd_ports FPGA_IO] [get_bd_ports WDI_EN]
  connect_bd_net -net WD_HIT [get_bd_pins WD_CTRL/WDI_HIT_OUT] [get_bd_ports WD_HIT]
  connect_bd_net -net axi_ethernetlite_0_ip2intc_irpt [get_bd_pins axi_ethernetlite_0/ip2intc_irpt] [get_bd_pins xlconcat_0/In0]
  connect_bd_net -net axi_ethernetlite_1_ip2intc_irpt [get_bd_pins axi_ethernetlite_1/ip2intc_irpt] [get_bd_pins xlconcat_0/In1]
  connect_bd_net -net processing_system7_0_FCLK_CLK0 [get_bd_pins processing_system7_0/FCLK_CLK0] [get_bd_pins WD_CTRL/FCLK_0_IN] [get_bd_pins axi_ethernetlite_0/s_axi_aclk] [get_bd_pins axi_ethernetlite_1/s_axi_aclk] [get_bd_pins processing_system7_0/M_AXI_GP0_ACLK] [get_bd_pins ps7_0_axi_periph/ACLK] [get_bd_pins ps7_0_axi_periph/M00_ACLK] [get_bd_pins ps7_0_axi_periph/M01_ACLK] [get_bd_pins ps7_0_axi_periph/S00_ACLK] [get_bd_pins rst_ps7_0_50M/slowest_sync_clk]
  connect_bd_net -net processing_system7_0_FCLK_RESET0_N [get_bd_pins processing_system7_0/FCLK_RESET0_N] [get_bd_pins rst_ps7_0_50M/ext_reset_in]
  connect_bd_net -net rst_ps7_0_50M_interconnect_aresetn [get_bd_pins rst_ps7_0_50M/interconnect_aresetn] [get_bd_pins ps7_0_axi_periph/ARESETN]
  connect_bd_net -net rst_ps7_0_50M_peripheral_aresetn [get_bd_pins rst_ps7_0_50M/peripheral_aresetn] [get_bd_pins axi_ethernetlite_0/s_axi_aresetn] [get_bd_pins axi_ethernetlite_1/s_axi_aresetn] [get_bd_pins ps7_0_axi_periph/M00_ARESETN] [get_bd_pins ps7_0_axi_periph/M01_ARESETN] [get_bd_pins ps7_0_axi_periph/S00_ARESETN]
  connect_bd_net -net xlconcat_0_dout [get_bd_pins xlconcat_0/dout] [get_bd_pins processing_system7_0/IRQ_F2P]

  # Create address segments
  assign_bd_address -offset 0x40E00000 -range 0x00010000 -target_address_space [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs axi_ethernetlite_0/S_AXI/Reg] -force
  assign_bd_address -offset 0x40E10000 -range 0x00010000 -target_address_space [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs axi_ethernetlite_1/S_AXI/Reg] -force


  # Restore current instance
  current_bd_instance $oldCurInst

  validate_bd_design
  save_bd_design
}
# End of create_root_design()


##################################################################
# MAIN FLOW
##################################################################

create_root_design ""



